@@ -1,24 +1,18 @@
 """
 utils
 """
-from __future__ import print_function, unicode_literals
 import inspect
 import warnings
 import sys
 import shlex
 import subprocess
 import os
-import io
 import platform
 import traceback
-import datetime
 
 
 DEBUG = bool(os.environ.get("SETUPTOOLS_SCM_DEBUG"))
 IS_WINDOWS = platform.system() == "Windows"
-PY2 = sys.version_info < (3,)
-PY3 = sys.version_info > (3,)
-string_types = (str,) if PY3 else (str, unicode)  # noqa
 
 
 def no_git_env(env):
@@ -64,7 +58,7 @@ def _always_strings(env_dict):
     On Windows and Python 2, environment dictionaries must be strings
     and not unicode.
     """
-    if IS_WINDOWS or PY2:
+    if IS_WINDOWS:
         env_dict.update((key, str(value)) for (key, value) in env_dict.items())
     return env_dict
 
@@ -112,7 +106,7 @@ def do(cmd, cwd="."):
 
 
 def data_from_mime(path):
-    with io.open(path, encoding="utf-8") as fp:
+    with open(path, encoding="utf-8") as fp:
         content = fp.read()
     trace("content", repr(content))
     # the complex conditions come from reading pseudo-mime-messages
@@ -121,35 +115,15 @@ def data_from_mime(path):
     return data
 
 
-class UTC(datetime.tzinfo):
-    _ZERO = datetime.timedelta(0)
-
-    def utcoffset(self, dt):
-        return self._ZERO
-
-    def tzname(self, dt):
-        return "UTC"
-
-    def dst(self, dt):
-        return self._ZERO
-
-
-utc = UTC()
-
-
 def function_has_arg(fn, argname):
     assert inspect.isfunction(fn)
 
-    if PY2:
-        argspec = inspect.getargspec(fn).args
-    else:
-
-        argspec = inspect.signature(fn).parameters
+    argspec = inspect.signature(fn).parameters
 
     return argname in argspec
 
 
-def has_command(name):
+def has_command(name, warn=True):
     try:
         p = _popen_pipes([name, "help"], ".")
     except OSError:
@@ -158,6 +132,11 @@ def has_command(name):
     else:
         p.communicate()
         res = not p.returncode
-    if not res:
-        warnings.warn("%r was not found" % name)
+    if not res and warn:
+        warnings.warn("%r was not found" % name, category=RuntimeWarning)
     return res
+
+
+def require_command(name):
+    if not has_command(name, warn=False):
+        raise OSError("%r was not found" % name)
